@@ -6,7 +6,7 @@ import org.jmx4perl.config.DebugStore;
 import org.jmx4perl.config.Restrictor;
 import org.jmx4perl.config.RestrictorFactory;
 import org.jmx4perl.converter.StringToObjectConverter;
-import org.jmx4perl.converter.json.ObjectToJsonConverter;
+import org.jmx4perl.converter.attribute.ObjectToJsonConverter;
 import org.jmx4perl.handler.*;
 import org.jmx4perl.history.HistoryStore;
 import org.json.simple.JSONObject;
@@ -62,7 +62,7 @@ import java.util.Map;
  * like strings or numbers, collections, arrays and maps are also supported (which
  * translate into the corresponding JSON structure). Additional the OpenMBean types
  * {@link javax.management.openmbean.CompositeData} and {@link javax.management.openmbean.TabularData}
- * are supported as well. Refer to {@link org.jmx4perl.converter.json.ObjectToJsonConverter}
+ * are supported as well. Refer to {@link org.jmx4perl.converter.attribute.ObjectToJsonConverter}
  * for additional information.
  *
  * For the client part, please read the documentation of
@@ -98,8 +98,8 @@ public class AgentServlet extends HttpServlet {
     private ObjectName configMBeanName;
 
     @Override
-    public void init(ServletConfig pConfig) throws ServletException {
-        super.init(pConfig);
+    public void init() throws ServletException {
+        super.init();
 
         // Get all MBean servers we can find. This is done by a dedicated
         // handler object
@@ -110,7 +110,7 @@ public class AgentServlet extends HttpServlet {
 
         // Central objects
         stringToObjectConverter = new StringToObjectConverter();
-        objectToJsonConverter = new ObjectToJsonConverter(stringToObjectConverter,pConfig);
+        objectToJsonConverter = new ObjectToJsonConverter(stringToObjectConverter);
 
         registerRequestHandler();
         registerOwnMBeans();
@@ -305,8 +305,6 @@ public class AgentServlet extends HttpServlet {
             } catch (MBeanRegistrationException e) {
                 log("Cannot unregister MBean: " + e,e);
             }
-        } else {
-            log("Internal Problem: No ConfigMBean name !");
         }
     }
 
